Generating a Single Structure

# 2 Generating a Single Structure

There are two methods of generating structures using `NanoCap`, producing structures individually or a batch of structures found using a structure search. Creation of a single structure is useful when it is required quickly and there is little need for the structure to be the lowest in energy.
A single structure is constructed via:
File–New Structure–Single Structure
which displays the current list of available structures in `NanoCap`:

Figure 1: `NanoCap` structure list for adding a single structure

Adding a structures produces a blank template containing no points or atoms. Each of the structures listed above are discussed in the following sections.

- 2.1 Fullerenes
- 2.2 Nanotubes
- 2.3 Capped Nanotubes